View source: R/rate_policies.R
| rate_policies_with_trace | R Documentation |
Apply a rating plan to every row and coverage in a policy-level data frame and retain step-by-step trace information.
rate_policies_with_trace(rating_data, plan, validate = TRUE)
rating_data |
A data frame containing one row per policy or rating record. |
plan |
A |
validate |
Logical. If |
A rating_result object containing:
The original records with indicated coverage values.
Step-by-step rating trace rows.
The rating plan used for the calculation.
ex <- example_rating_plan()
result <- rate_policies_with_trace(
rating_data = ex$policies,
plan = ex$plan
)
result$rated_data
result$term_trace
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.