score_entity_rows: Score child or entity records

View source: R/entities.R

score_entity_rowsR Documentation

Score child or entity records

Description

Score entity records without constructing trace output. This uses rate_policies() so supported standard plans can use the optimized vectorized batch-rating engine.

Usage

score_entity_rows(entity_data, plan, validate = TRUE)

Arguments

entity_data

A data frame containing one row per entity to be rated.

plan

A rating_plan object created by new_rating_plan().

validate

Logical. If TRUE, validate the entity data before rating.

Value

A data frame containing the original entity data and calculated indicated values.

Examples

ex <- example_rating_plan()

drivers <- ex$policies
drivers$household_id <- "H1"
drivers$policy_id <- c("D1", "D2")

scored <- score_entity_rows(
  entity_data = drivers,
  plan = ex$plan
)

scored

ratingtables documentation built on Sept. 6, 2026, 1:06 a.m.