validate_rating_plan: Check a rating plan

View source: R/validation.R

validate_rating_planR Documentation

Check a rating plan

Description

Run factor-table, rating-specification, and rate-set checks and confirm that custom functions referenced by the specification are registered as functions in the plan.

Usage

validate_rating_plan(plan)

Arguments

plan

A rating_plan object created by new_rating_plan().

Value

Invisibly returns TRUE if validation succeeds. Otherwise, the function stops with an error.

Examples

ex <- example_rating_plan()

isTRUE(
  validate_rating_plan(ex$plan)
)

ratingtables documentation built on Sept. 6, 2026, 1:06 a.m.