View source: R/trace_helpers.R
| explain_rating | R Documentation |
Extract and format the rating trace for one source-data row and, optionally, one coverage.
explain_rating(rating_result, row_number = 1, coverage = NULL)
rating_result |
A |
row_number |
An integer identifying the source-data row to explain. |
coverage |
An optional character string identifying the coverage to
include. If |
An Excel-style data frame showing the selected rating steps in calculation order.
ex <- example_rating_plan()
result <- rate_policies_with_trace(
ex$policies,
ex$plan
)
explain_rating(
rating_result = result,
row_number = 1,
coverage = "BI"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.