| lookup_exact_value | R Documentation |
Select the single most specific factor-table row that matches a rating record, coverage, term, rate-set metadata, and variable-level conditions.
lookup_exact_value(row, coverage, plan, term_name)
row |
A one-row data frame containing the rating record. |
coverage |
A character string identifying the coverage being rated. |
plan |
A |
term_name |
A character string identifying the rating term to look up. |
A list containing the selected numeric value, the value source, the looked-up value, and the matching factor-row identifier.
ex <- example_rating_plan()
policy <- ex$policies[1, , drop = FALSE]
answer <- lookup_exact_value(
row = policy,
coverage = "BI",
plan = ex$plan,
term_name = "territory"
)
answer$value
answer$factor_row_id
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.