| lookup_factor_value | R Documentation |
Dispatch a rating-table lookup to either exact matching or interpolated
lookup according to value_source.
lookup_factor_value(
row,
coverage,
plan,
term_name,
value_source = "factor_lookup",
lookup_var = NULL,
bounds = "error"
)
row |
A one-row data frame containing the rating record. |
coverage |
A character string identifying the coverage being rated. |
plan |
A |
term_name |
A character string identifying the rating term to look up. |
value_source |
A character string specifying the lookup method.
Supported values are |
lookup_var |
An optional character string naming the interpolation
variable. Required for |
bounds |
A character string controlling out-of-range interpolation.
Supported values are |
A list containing the selected or interpolated rating value and associated trace information.
ex <- example_rating_plan()
policy <- ex$policies[1, , drop = FALSE]
answer <- lookup_factor_value(
row = policy,
coverage = "BI",
plan = ex$plan,
term_name = "territory",
value_source = "factor_lookup"
)
answer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.