| populate_slots | R Documentation |
Populate variable/level slots from named values
populate_slots(x, ..., max_vars = 12)
x |
A data frame to which slot columns will be added or updated. |
... |
Named vectors of levels. Each argument name becomes the value of
a |
max_vars |
A nonnegative integer giving the maximum number of variable-level slot pairs. |
A data frame containing x with variable and level slot columns
populated from the named values supplied through ....
factors <- data.frame(
term_name = c("territory_limit", "territory_limit"),
term_value = c(1.10, 0.95)
)
factors <- populate_slots(
factors,
territory = c("A", "B"),
limit = "100/300",
max_vars = 2
)
factors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.