| rate_one_row_one_coverage | R Documentation |
Execute the applicable rating specification one step at a time for a single record and coverage.
rate_one_row_one_coverage(row, coverage, plan, row_number = 1)
row |
A one-row data frame containing the rating record. |
coverage |
A character string identifying the coverage to rate. |
plan |
A |
row_number |
An integer identifying the row within the source rating data. This value is included in the trace output. |
A list with two elements: value, containing the final indicated
value, and trace, containing one trace row per rating-specification step.
ex <- example_rating_plan()
answer <- rate_one_row_one_coverage(
row = ex$policies[1, , drop = FALSE],
coverage = "BI",
plan = ex$plan,
row_number = 1
)
answer$value
answer$trace
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.