View source: R/rate_policies.R
| rate_policies | R Documentation |
Apply a rating plan to every row and coverage in a policy-level data frame, returning only the resulting rated data. Plans using supported standard rating operations are evaluated with a vectorized batch engine. Plans using unsupported operations fall back to the general trace-capable engine.
rate_policies(rating_data, plan, validate = TRUE)
rating_data |
A data frame containing one row per policy or rating record. |
plan |
A |
validate |
Logical. If |
A data frame containing the original rating data plus one
indicated_<coverage> column for each coverage in the rating plan.
ex <- example_rating_plan()
rated <- rate_policies(
rating_data = ex$policies,
plan = ex$plan
)
rated
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.