| score_entity_rows | R Documentation |
Score entity records without constructing trace output. This uses
rate_policies() so supported standard plans can use the optimized
vectorized batch-rating engine.
score_entity_rows(entity_data, plan, validate = TRUE)
entity_data |
A data frame containing one row per entity to be rated. |
plan |
A |
validate |
Logical. If |
A data frame containing the original entity data and calculated indicated values.
ex <- example_rating_plan()
drivers <- ex$policies
drivers$household_id <- "H1"
drivers$policy_id <- c("D1", "D2")
scored <- score_entity_rows(
entity_data = drivers,
plan = ex$plan
)
scored
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.