View source: R/trace_helpers.R
| trace_to_excel_style | R Documentation |
Select and order the principal trace columns to produce a compact, human-readable view of the rating calculation.
trace_to_excel_style(term_trace)
term_trace |
A data frame containing normalized rating trace rows,
typically from |
A data frame ordered by row number, coverage, and step number. It
contains the available columns among row_number, record_id, coverage,
step_number, term_name, value_source, calculation_type,
applied_value, value_before_step, and value_after_step.
ex <- example_rating_plan()
result <- rate_policies_with_trace(
ex$policies,
ex$plan
)
trace_to_excel_style(
result$term_trace
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.