| validate_rate_sets | R Documentation |
Check that rate_set_key contains no missing or blank values when present,
and that rate_eff_date is not later than rate_exp_date when both date
columns are present.
validate_rate_sets(factor_table)
factor_table |
A data frame containing rating factors and optional rate-set fields. |
Invisibly returns TRUE if validation succeeds. Otherwise, the
function stops with an error.
ex <- example_rating_plan()
isTRUE(
validate_rate_sets(
ex$plan$factor_table
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.