| validate_rating_plan | R Documentation |
Run factor-table, rating-specification, and rate-set checks and confirm that custom functions referenced by the specification are registered as functions in the plan.
validate_rating_plan(plan)
plan |
A |
Invisibly returns TRUE if validation succeeds. Otherwise, the
function stops with an error.
ex <- example_rating_plan()
isTRUE(
validate_rating_plan(ex$plan)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.