| validate_rating_spec | R Documentation |
Normalize a rating specification and check its value sources, calculation types, and required lookup, input, or custom-function fields.
validate_rating_spec(rating_spec, ...)
rating_spec |
A data frame containing the rating specification. It must
contain |
... |
Additional arguments accepted for backward compatibility and currently ignored. |
Invisibly returns TRUE if validation succeeds. Otherwise, the
function stops with an error.
ex <- example_rating_plan()
isTRUE(
validate_rating_spec(
ex$plan$rating_spec
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.